==> commons-io-2.17.0-src.tar.gz: commons-io-2.17.0-src/src/test/java/org/apache/commons/io/serialization/FullClassNameMatcherTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.commons.io.serialization;

import static org.junit.jupiter.api.Assertions.assertFalse;
import static org.junit.jupiter.api.Assertions.assertTrue;

import org.junit.jupiter.api.Test;

/**
 * Tests {@link FullClassNameMatcher}.
 */
public class FullClassNameMatcherTest {

    private static final String [] NAMES_ARRAY = { Integer.class.getName(), Long.class.getName() };

    @Test
    public void testNoNames() {
        final FullClassNameMatcher m = new FullClassNameMatcher();
        assertFalse(m.matches(Integer.class.getName()));
    }

    @Test
    public void testWithNames() {
        final FullClassNameMatcher m = new FullClassNameMatcher(NAMES_ARRAY);
        assertTrue(m.matches(Integer.class.getName()));
        assertFalse(m.matches(String.class.getName()));
    }
}

==> commons-io-2.20.0-src.tar.gz: commons-io-2.20.0-src/src/test/java/org/apache/commons/io/serialization/FullClassNameMatcherTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.commons.io.serialization;

import static org.junit.jupiter.api.Assertions.assertFalse;
import static org.junit.jupiter.api.Assertions.assertTrue;

import org.junit.jupiter.api.Test;

/**
 * Tests {@link FullClassNameMatcher}.
 */
class FullClassNameMatcherTest {

    private static final String [] NAMES_ARRAY = { Integer.class.getName(), Long.class.getName() };

    @Test
    void testNoNames() {
        final FullClassNameMatcher m = new FullClassNameMatcher();
        assertFalse(m.matches(Integer.class.getName()));
    }

    @Test
    void testWithNames() {
        final FullClassNameMatcher m = new FullClassNameMatcher(NAMES_ARRAY);
        assertTrue(m.matches(Integer.class.getName()));
        assertFalse(m.matches(String.class.getName()));
    }
}
